@@ -1,6 +1,5 @@
 from .listfromtxt import listfromtxt
 from .txtfromlist import txtfromlist
-from .lists import newlists
-
-
+from .lists import Lists
+from simplelist import *
 
